pub struct TypstText {
chars: String,
vitems: Vec<VItem>,
}Expand description
A Text item construted through typst
Note that the methods this item provides assumes that the typst string you provide only produces text output, otherwise undefined behaviours may happens.
Fields
chars: Stringvitems: Vec<VItem>Implementations
Sourceimpl TypstText
impl TypstText
fn _new(str: &str) -> Self
Sourcepub fn new(typst_str: &str) -> Self
pub fn new(typst_str: &str) -> Self
Create a TypstText with typst string.
The typst string you provide should only produces text output, otherwise undefined behaviours may happens.
Sourcepub fn new_inline_code(code: &str) -> Self
pub fn new_inline_code(code: &str) -> Self
Inline code
Sourcepub fn new_multiline_code(code: &str, language: Option<&str>) -> Self
pub fn new_multiline_code(code: &str, language: Option<&str>) -> Self
Multiline code